==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/PrimitiveArrayFileSize.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o;

namespace com.db4o.test
{
	public class PrimitiveArrayFileSize
	{
        Object arr;
	
        public void testSimpleLongInObject(){
            int call = 0;
            PrimitiveArrayFileSize pafs = new PrimitiveArrayFileSize();
            for (int i = 0; i < 12; i++) {
                pafs.arr = new long[100];
                Tester.store(pafs);
                checkFileSize(call++);
                Tester.commit();
                checkFileSize(call++);
            }
        }
	
        public void testLongWrapperInObject(){
            int call = 0;
            PrimitiveArrayFileSize pafs = new PrimitiveArrayFileSize();
            for (int i = 0; i < 12; i++) {
                pafs.arr = longWrapperArray();
                Tester.store(pafs);
                checkFileSize(call++);
                Tester.commit();
                checkFileSize(call++);
            }
        }
	
//        public void testSimpleLongInHashMap(){
//            HashMap hm = new HashMap();
//            int call = 0;
//            for (int i = 0; i < 12; i++) {
//                long[] lll = new long[100];
//                lll[0] = 99999;
//                hm.put("test", lll);
//                Tester.store(hm);
//                checkFileSize(call++);
//                Tester.commit();
//                checkFileSize(call++);
//            }
//        }
	
//        public void testLongWrapperInHashMap(){
//            HashMap hm = new HashMap();
//            int call = 0;
//            for (int i = 0; i < 12; i++) {
//                hm.put("test", longWrapperArray());
//                Tester.store(hm);
//                checkFileSize(call++);
//                Tester.commit();
//                checkFileSize(call++);
//            }
//        }
	
	
        private long[] longWrapperArray(){
            long[] larr = new long[100];
            for (int j = 0; j < larr.Length; j++) {
                larr[j] = j;
            }
            return larr;
        }
	
	
	
        private void checkFileSize(int call){
            if(Tester.canCheckFileSize()){
                int newFileLength = Tester.fileLength();
			
                // Interesting for manual tests:
                // Console.WriteLine(newFileLength);
			
                if(call == 6){
                    // consistency reached, start testing
                    jumps = 0;
                    fileLength = newFileLength;
                }else if(call > 6){
                    if(newFileLength > fileLength){
                        if(jumps < 4){
                            fileLength = newFileLength;
                            jumps ++;
                            // allow two further step in size
                            // may be necessary for commit space extension
                        }else{
                            // now we want constant behaviour
                            Tester.error();
                        }
                    }
                }
            }
        }
	
        [Transient]
        private static int fileLength;
        [Transient]
        private static int jumps; 
	
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/PrimitiveArrayFileSize.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o;

namespace com.db4o.test
{
	public class PrimitiveArrayFileSize
	{
        Object arr;
	
        public void TestSimpleLongInObject(){
            int call = 0;
            PrimitiveArrayFileSize pafs = new PrimitiveArrayFileSize();
            for (int i = 0; i < 12; i++) {
                pafs.arr = new long[100];
                Tester.Store(pafs);
                CheckFileSize(call++);
                Tester.Commit();
                CheckFileSize(call++);
            }
        }
	
        public void TestLongWrapperInObject(){
            int call = 0;
            PrimitiveArrayFileSize pafs = new PrimitiveArrayFileSize();
            for (int i = 0; i < 12; i++) {
                pafs.arr = LongWrapperArray();
                Tester.Store(pafs);
                CheckFileSize(call++);
                Tester.Commit();
                CheckFileSize(call++);
            }
        }
	
//        public void TestSimpleLongInHashMap(){
//            HashMap hm = new HashMap();
//            int call = 0;
//            for (int i = 0; i < 12; i++) {
//                long[] lll = new long[100];
//                lll[0] = 99999;
//                hm.Put("test", lll);
//                Tester.Store(hm);
//                CheckFileSize(call++);
//                Tester.Commit();
//                CheckFileSize(call++);
//            }
//        }
	
//        public void TestLongWrapperInHashMap(){
//            HashMap hm = new HashMap();
//            int call = 0;
//            for (int i = 0; i < 12; i++) {
//                hm.Put("test", LongWrapperArray());
//                Tester.Store(hm);
//                CheckFileSize(call++);
//                Tester.Commit();
//                CheckFileSize(call++);
//            }
//        }
	
	
        private long[] LongWrapperArray(){
            long[] larr = new long[100];
            for (int j = 0; j < larr.Length; j++) {
                larr[j] = j;
            }
            return larr;
        }
	
	
	
        private void CheckFileSize(int call){
            if(Tester.CanCheckFileSize()){
                int newFileLength = Tester.FileLength();
			
                // Interesting for manual tests:
                // Console.WriteLine(newFileLength);
			
                if(call == 6){
                    // consistency reached, start testing
                    jumps = 0;
                    fileLength = newFileLength;
                }else if(call > 6){
                    if(newFileLength > fileLength){
                        if(jumps < 4){
                            fileLength = newFileLength;
                            jumps ++;
                            // allow two further step in size
                            // may be necessary for commit space extension
                        }else{
                            // now we want constant behaviour
                            Tester.Error();
                        }
                    }
                }
            }
        }
	
        [Transient]
        private static int fileLength;
        [Transient]
        private static int jumps; 
	
    }
}
